/*
 *	fhist - file history and comparison tools
 *	Copyright (C) 1999, 2002 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: functions to determione directory-ness
 */

#include <sys/types.h>
#include <sys/stat.h>

#include <isdir.h>


/*
 * Determine if an argument is a directory.
 * Returns 1 if so, or 0 if non-existent or not.
 */

int
isdir(const char *pathname)
{
    struct stat     buf;

    if (stat(pathname, &buf) < 0)
       	return 0;
    return S_ISDIR(buf.st_mode);
}
